@@ -7,6 +7,7 @@ use lazy_static::lazy_static;
 use std::sync::Mutex;
 use std::{
     collections::HashSet,
+    env,
     error::Error,
     fmt::{Debug, Display},
 };
@@ -14,6 +15,9 @@ use std::{
 lazy_static! {
     // avoid out-of-order printing
     static ref LOG_LK: Mutex<()> = Mutex::new(());
+    static ref RUC_OUT: bool = env::var("RUC_OUT")
+                .map(|_str|true)
+                .unwrap_or_else(|_|false);
 }
 
 /// Custom Result
@@ -162,7 +166,12 @@ pub trait RucError: Display + Debug + Send {
     #[inline(always)]
     fn print(&self, prefix: Option<&str>) {
         if LOG_LK.lock().is_ok() {
-            eprintln!("{}", self.generate_log(prefix));
+            match &*RUC_OUT {
+                true => {
+                    eprintln!("{}", self.generate_log(prefix));
+                }
+                false => {}
+            }
         }
     }
 
